# Paks

> Paks is a framework for building community packages and containers 📦️

## Goals

We want a framework that is optimized to help people build packages from source,
and distribute the binaries via GitHub packages and also provide robust metadata
and an organization scheme that works well for containers. We want a focus on that
and then testing and automatically updating the individual packages provided.
Paks provides this functionality by wrapping spack to perform builds, and then
providing tooling to release to a GitHub packages build cache.

🚧️ **under development** 🚧️

